==> haskell-pem-0.2.4-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pem
version:              0.2.4
visibility:           public
id:                   pem-0.2.4-KtuSWjFccmLKGaTDaqFOVd
key:                  pem-0.2.4-KtuSWjFccmLKGaTDaqFOVd
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-pem
synopsis:             Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description

category:             Data
abi:                  9b8c6705af9045ba005941f5a440e02e
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pem
hs-libraries:         HSpem-0.2.4-KtuSWjFccmLKGaTDaqFOVd
depends:
    base-4.15.1.0 basement-0.0.15-IvZTyCKoUdE3jMkDdiQhQ0
    bytestring-0.10.12.1 memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b

haddock-interfaces:   /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html:         /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pem-0.2.4-252-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pem
version:              0.2.4
visibility:           public
id:                   pem-0.2.4-24PX2rj9TyTCtyHY8MTt8f
key:                  pem-0.2.4-24PX2rj9TyTCtyHY8MTt8f
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-pem
synopsis:             Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description

category:             Data
abi:                  0cfb4e1c5385f38afe70bfeeb58179b4
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pem
hs-libraries:         HSpem-0.2.4-24PX2rj9TyTCtyHY8MTt8f
depends:
    base-4.15.1.0 basement-0.0.15-IvZTyCKoUdE3jMkDdiQhQ0
    bytestring-0.10.12.1 memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b

haddock-interfaces:   /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html:         /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
